@@ -43,7 +43,8 @@ using namespace Kerfuffle;
 void Cli7zTest::initTestCase()
 {
     m_plugin = new Plugin(this);
-    foreach (Plugin *plugin, m_pluginManger.availablePlugins()) {
+    const auto plugins = m_pluginManger.availablePlugins();
+    for (Plugin *plugin : plugins) {
         if (plugin->metaData().pluginId() == QStringLiteral("kerfuffle_cli7z")) {
             m_plugin = plugin;
             return;
@@ -463,7 +464,7 @@ void Cli7zTest::testExtractArgs()
 
     QFETCH(QVector<Archive::Entry*>, files);
     QStringList filesList;
-    foreach (const Archive::Entry *e, files) {
+    for (const Archive::Entry *e : qAsConst(files)) {
         filesList << e->fullPath(NoTrailingSlash);
     }
 
