@@ -33,7 +33,6 @@
 #include "mimetypes.h"
 #include "pluginmanager.h"
 
-#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginLoader>
 
@@ -62,7 +61,7 @@ Archive *Archive::create(const QString &fileName, const QString &fixedMimeType,
     }
 
     Archive *archive = nullptr;
-    foreach (Plugin *plugin, offers) {
+    for (Plugin *plugin : offers) {
         archive = create(fileName, plugin, parent);
         // Use the first valid plugin, according to the priority sorting.
         if (archive->isValid()) {
